@@ -24,6 +24,8 @@ use self::melswap::PoolMapping;
 mod applytx;
 pub(crate) mod melmint;
 pub(crate) mod melswap;
+mod poolkey;
+pub use poolkey::PoolKey;
 
 // TODO: Move these structs into state package
 // ie: split this into modules such as
@@ -352,7 +354,7 @@ impl State {
         self = preseal_melmint(self);
         assert!(self.pools.val_iter().count() >= 2);
 
-        let after_tip_901 = self.height >= 42700;
+        let after_tip_901 = self.height >= TIP_901_HEIGHT;
 
         // apply the proposer action
         if let Some(action) = action {
@@ -518,9 +520,8 @@ impl SealedState {
                 block.header,
                 transactions.len()
             );
-            assert!(basis.inner_ref().pools.val_iter().count() >= 2);
-            for pool_info in basis.inner_ref().pools.val_iter() {
-                dbg!(pool_info);
+            for tx in block.transactions.iter() {
+                log::warn!("{:?}", tx);
             }
             return Err(StateError::WrongHeader);
         }
